starcluster.static

Package starcluster :: Module static |
[hide private]
[frames] | no frames]

# Module static

source code

Module for storing static data structures

Functions | [hide private]
__expand_all(path) | source code
__makedirs(path, exit_on_failure=False) | source code
create_sc_config_dirs() | source code

Variables | [hide private]
| VERSION = ``'``0.92.1``'``
| PID = `16877`
| TMP_DIR = ``'``/tmp``'``
| CURRENT_USER = ``'``jtriley``'``
| SSH_TEMPLATE = ``'``ssh -i %s %s@%s``'``
| STARCLUSTER_CFG_DIR = ``'``/home/jtriley/.starcluster``'``
| STARCLUSTER_CFG_FILE = ``'``/home/jtriley/.starcluster/config``'``
| STARCLUSTER_PLUGIN_DIR = ``'``/home/jtriley/.starcluster/plugins``'``
| STARCLUSTER_LOG_DIR = ``'``/home/jtriley/.starcluster/logs``'``
| STARCLUSTER_RECEIPT_DIR = ``'``/var/run/starcluster``'``
| STARCLUSTER_RECEIPT_FILE = ``'``/var/run/starcluster/receipt.pkl``'``
| STARCLUSTER_OWNER_ID = `342652561657`
| DEBUG_FILE = ``'``/home/jtriley/.starcluster/logs/debug.log``'``
| SSH_DEBUG_FILE = ``'``/home/jtriley/.starcluster/logs/ssh-debug.log``'``
| AWS_DEBUG_FILE = ``'``/home/jtriley/.starcluster/logs/aws-debug.log``'``
| CRASH_FILE = ``'``/home/jtriley/.starcluster/logs/crash-report-168``...``
| BASE_AMI_32 = ``'``ami-8cf913e5``'``
| BASE_AMI_64 = ``'``ami-0af31963``'``
| SECURITY_GROUP_PREFIX = ``'``@sc``'``
| SECURITY_GROUP_TEMPLATE = ``'``@sc-%s``'``
| MASTER_GROUP_NAME = ``'``masters``'``
| MASTER_GROUP = ``'``@sc-masters``'``
| MASTER_GROUP_DESCRIPTION = ``'``StarCluster Master Nodes``'``
| VOLUME_GROUP_NAME = ``'``volumecreator``'``
| VOLUME_GROUP = ``'``@sc-volumecreator``'``
| IGNORE_GROUPS = ``[``'``@sc-masters``'``]``
| INSTANCE_STATES = ``[``'``pending``'``,` `'``running``'``,` `'``shutting-down``'``,` `'``ter``...``
| VOLUME_STATUS = ``[``'``creating``'``,` `'``available``'``,` `'``in-use``'``,` `'``deleting``'``...``
| VOLUME_ATTACH_STATUS = ``[``'``attaching``'``,` `'``attached``'``,` `'``detaching``'``,` `...``
| INSTANCE_TYPES = ``{``'``c1.medium``'``:` `[``'``i386``'``]``,` `'``c1.xlarge``'``:` `[``'``x86_64``...``
| MICRO_INSTANCE_TYPES = ``[``'``t1.micro``'``]``
| CLUSTER_COMPUTE_TYPES = ``[``'``cc1.4xlarge``'``]``
| CLUSTER_GPU_TYPES = ``[``'``cg1.4xlarge``'``]``
| CLUSTER_TYPES = ``[``'``cc1.4xlarge``'``,` `'``cg1.4xlarge``'``]``
| CLUSTER_REGIONS = ``[``'``us-east-1``'``]``
| PROTOCOLS = ``[``'``tcp``'``,` `'``udp``'``,` `'``icmp``'``]``
| WORLD_CIDRIP = ``'``0.0.0.0/0``'``
| DEFAULT_SSH_PORT = `22`
| AVAILABLE_SHELLS = ``{``'``bash``'``:` True`,` `'``csh``'``:` True`,` `'``ksh``'``:` True`,` `'``t``...``
| GLOBAL_SETTINGS = ``{``'``default_template``'``:` `(`<type 'str'>`,` False`,` N`...``
| AWS_SETTINGS = ``{``'``aws_access_key_id``'``:` `(`<type 'str'>`,` True`,` None`...``
| KEY_SETTINGS = ``{``'``key_location``'``:` `(`<type 'str'>`,` True`,` None`,` Non`...``
| EBS_VOLUME_SETTINGS = ``{``'``device``'``:` `(`<type 'str'>`,` False`,` None`,` N`...``
| PLUGIN_SETTINGS = ``{``'``setup_class``'``:` `(`<type 'str'>`,` True`,` None`,` N`...``
| PERMISSION_SETTINGS = ``{``'``cidr_ip``'``:` `(`<type 'str'>`,` False`,` `'``0.0.0``...``
| CLUSTER_SETTINGS = ``{``'``availability_zone``'``:` `(`<type 'str'>`,` False`,``...``
| __package__ = ``'``starcluster``'``

Variables Details | [hide private]

  ### CRASH_FILE Value:
      '/home/jtriley/.starcluster/logs/crash-report-16877.txt'

  ### INSTANCE_STATES Value:
      ['pending',
       'running',
       'shutting-down',
       'terminated',
       'stopping',
       'stopped']

  ### VOLUME_STATUS Value:
      ['creating', 'available', 'in-use', 'deleting', 'deleted', 'error']

  ### VOLUME_ATTACH_STATUS Value:
      ['attaching', 'attached', 'detaching', 'detached']

  ### INSTANCE_TYPES Value:
      {'c1.medium': ['i386'],
       'c1.xlarge': ['x86_64'],
       'cc1.4xlarge': ['x86_64'],
       'cg1.4xlarge': ['x86_64'],
       'm1.large': ['x86_64'],
       'm1.small': ['i386'],
       'm1.xlarge': ['x86_64'],
       'm2.2xlarge': ['x86_64'],
      ...

  ### AVAILABLE_SHELLS Value:
      {'bash': True, 'csh': True, 'ksh': True, 'tcsh': True, 'zsh': True}

  ### GLOBAL_SETTINGS Value:
      {'default_template': (<type 'str'>, False, None, None, None),
       'enable_experimental': (<type 'bool'>, False, False, None, None),
       'include': (<type 'list'>, False, [], None, None),
       'refresh_interval': (<type 'int'>, False, 30, None, None),
       'web_browser': (<type 'str'>, False, None, None, None)}

  ### AWS_SETTINGS Value:
      {'aws_access_key_id': (<type 'str'>, True, None, None, None),
       'aws_ec2_path': (<type 'str'>, False, '/', None, None),
       'aws_is_secure': (<type 'bool'>, False, True, None, None),
       'aws_port': (<type 'int'>, False, None, None, None),
       'aws_region_host': (<type 'str'>, False, None, None, None),
       'aws_region_name': (<type 'str'>, False, None, None, None),
       'aws_s3_host': (<type 'str'>, False, None, None, None),
       'aws_s3_path': (<type 'str'>, False, '/', None, None),
      ...

  ### KEY_SETTINGS Value:
      {'key_location': (<type 'str'>,
                        True,
                        None,
                        None,
                        <function __expand_all at 0x1512c80>)}

  ### EBS_VOLUME_SETTINGS Value:
      {'device': (<type 'str'>, False, None, None, None),
       'mount_path': (<type 'str'>, True, None, None, None),
       'partition': (<type 'int'>, False, None, None, None),
       'volume_id': (<type 'str'>, True, None, None, None)}

  ### PLUGIN_SETTINGS Value:
      {'setup_class': (<type 'str'>, True, None, None, None)}

  ### PERMISSION_SETTINGS Value:
      {'cidr_ip': (<type 'str'>, False, '0.0.0.0/0', None, None),
       'from_port': (<type 'int'>, True, None, None, None),
       'ip_protocol': (<type 'str'>,
                       False,
                       'tcp',
                       ['tcp', 'udp', 'icmp'],
                       None),
       'to_port': (<type 'int'>, True, None, None, None)}

  ### CLUSTER_SETTINGS Value:
      {'availability_zone': (<type 'str'>, False, None, None, None),
       'cluster_shell': (<type 'str'>,
                         False,
                         'bash',
                         ['tcsh', 'zsh', 'csh', 'bash', 'ksh'],
                         None),
       'cluster_size': (<type 'int'>, True, None, None, None),
       'cluster_user': (<type 'str'>, False, 'sgeadmin', None, None),
      ...